<?php

/***************** Customize form data display *****************/
// First step: Modify booking-form-single.html file!

// First, delete the default filter - if necessary
remove_filter('book_an_appointment_961_booking_content', 'book_an_appointment_961_booking_render_content_html');
 
// Define the new procedure
function my_booking_render_content_html($data) {
    $data = unserialize($data);
    // Modify this block to suit your needs
    $html = '<strong>'.$data['name'].'</strong>' .
            '<div class="small">'.$data['phone'].'</div>' .
            '<div class="small"><a href="mailto:'.$data['email'].'">'.$data['email'].'</a></div>';
    if ((isset($data['city'])) and (!empty($data['city']))) {
        $html .= '<div class="small">'.$data['city'].'</div>';
    } 
    // End of block to be modified
    return $html;
}
// Use the new filter
add_filter('book_an_appointment_961_booking_content', 'my_booking_render_content_html', 11, 1);

/***************** Customize month table *****************/

// Load customize style and script
function my_booking_styles_and_scripts() {

    if (file_exists(get_stylesheet_directory() .DS. 'book-an-appointment' .DS. 'booking.css')) {
        wp_register_style('my-booking', get_stylesheet_directory_uri(). DS. 'book-an-appointment' .DS. 'booking.css' );
        wp_enqueue_style('my-booking');
    }
    if (file_exists(get_stylesheet_directory() .DS. 'book-an-appointment' .DS. 'booking.js')) {
    	wp_register_script('my-booking-js', get_stylesheet_directory_uri() .DS. 'book-an-appointment' .DS. 'booking.js', array('jquery'), null, true);
    	wp_enqueue_script('my-booking-js');
    }

}
add_action( 'get_footer', 'my_booking_styles_and_scripts', 999 );

// Customize table 
remove_filter( 'book_an_appointment_month_table_before', 'book_an_appointment_961_month_table_before');
function my_booking_month_table_before($month) {
    
    $options = book_an_appointment_961_get_options();
    $html = "\r\n". '<div class="booking-month-name">'.date_i18n($options['date_format'], strtotime($month.'-01')).'</div>' . "\r\n" .
            "\t" . '<div class="booking-container" data-month="'.$month.'">' . "\r\n";
    
    return $html;
}
add_filter( 'book_an_appointment_month_table_before', 'my_booking_month_table_before', 11, 1 );

remove_filter( 'book_an_appointment_month_table_after', 'book_an_appointment_961_month_table_after');
function my_booking_month_table_after() {
    
    $html = '</div>' . "\r\n";
    
    return $html;
}
add_filter( 'book_an_appointment_month_table_after', 'my_booking_month_table_after', 11 );

// Delete table row items 
remove_filter( 'book_an_appointment_week_before', 'book_an_appointment_961_week_before');
remove_filter( 'book_an_appointment_week_before', 'book_an_appointment_961_week_after');


// Modify month header
remove_filter( 'book_an_appointment_month_table_header', 'book_an_appointment_961_month_table_header');
function my_booking_month_table_header($days) {
            
    $html = "\t" . '<div class="item days">'.implode('</div>'."\r\n\t".'<div class="item days">', $days).'</div>' . "\r\n" .
            "\t" . '<div style="width:100%"><hr style="margin: 2px 0;" /></div>' . "\r\n";           

    return $html;
}
add_filter( 'book_an_appointment_month_table_header', 'my_booking_month_table_header', 11, 1 );

// Modify empty day block
remove_filter( 'book_an_appointment_empty_day', 'book_an_appointment_961_empty_day');
function my_booking_empty_day() {
    return "\t" . '<div class="item empty">&nbsp;</div>' . "\r\n";
}
add_filter( 'book_an_appointment_empty_day', 'my_booking_empty_day', 10);

// Modify one day block
remove_filter( 'book_an_appointment_one_day', 'book_an_appointment_961_one_day');
function my_booking_one_day($class, $script, $id, $day) {
    
    $html = "\t" . '<div class="item '.implode(' ', $class).'" '.$script.' data-day="'.$id.'">'.$day.'</div>' . "\r\n";
    
    return $html;
}
add_filter( 'book_an_appointment_one_day', 'my_booking_one_day', 11, 4);

// Modify NEXT link
remove_filter( 'book_an_appointment_next_link', 'book_an_appointment_961_next_link');
function my_booking_next_link($month, $script) {
    
    $next = date('Y-m', strtotime('+1 month', strtotime($month.'-01')));
    $html = "\t" . '<div class="button next_month" '.$script.'>' . "\r\n" . 
            "\t\t" . date_i18n('F', strtotime($next)) . "\r\n" .
            "\t\t" . '<span class="dashicons dashicons-arrow-right"></span>' . "\r\n" . 
            "\t" . '</div>' . "\r\n";
    
    return $html;
}
add_filter( 'book_an_appointment_next_link', 'my_booking_next_link', 11, 2);

// Modify PREV link
remove_filter( 'book_an_appointment_prev_link', 'book_an_appointment_961_prev_link');
function my_booking_prev_link($month, $script, $mode) {
    
    $html = '';
    if (($mode == 'time') and ($month > date('Y-m'))) {
        $prev = date('Y-m', strtotime('-1 month', strtotime($month.'-01')));
        $html = "\t" . '<div class="button prev_month" '.$script.'>' . "\r\n" . 
                "\t\t" . '<span class="dashicons dashicons-arrow-left"></span>' . "\r\n" . 
                "\t\t" . date_i18n('F', strtotime($prev)) . "\r\n" .
                "\t" . '</div>' . "\r\n";
    }    
    return $html;
}
add_filter( 'book_an_appointment_prev_link', 'my_booking_prev_link', 11, 3);

// Modify month footer
remove_filter( 'book_an_appointment_month_table_footer', 'book_an_appointment_961_month_table_footer');
function my_booking_month_table_footer($prev, $next) {
    
    $html = "\t" . '</div>' . "\r\n" .
            "\t" . '<div style="margin-top:4px;">' . "\r\n" .
            $prev . 
            $next .
            "\t" . '</div>' . "\r\n" . 
            "\t" . '<div style="clear:both;"></div>' . "\r\n";
    
    return $html;
}
add_filter( 'book_an_appointment_month_table_footer', 'my_booking_month_table_footer', 11, 2);

// Modify time block
remove_filter( 'book_an_appointment_one_time', 'book_an_appointment_961_one_time');
function book_an_appointment_961_one_time($time, $script, $class = '') {
    
    $html = '<div '.$script.' class="appointment-time '.$class.'" data-time="'.$time.'">'.$time.'</div>';
    return $html;
}
add_filter( 'book_an_appointment_one_time', 'book_an_appointment_961_one_time', 10, 3);

// Translate override
function my_booking_translate_text( $translation, $text, $domain ) {
    if ( $domain === 'book-an-appointment' ) {
        
        // We only ask once
        if (!defined('BOOKING_LOCALE')) {
            define('BOOKING_LOCALE', get_locale());                
        }
        
        switch ($text){ 
            case 'Your name:':
                // Modify if required
                // $translation = 'Name:';
                break;
            case 'Your email:':
                break;
            case 'We will send a confirmation link to this address.':
                break;
            case 'Your phone:':
                break;
            case 'Your message:':
                break;
            case 'I\'m booking':
                break;
                
            case 'I accept the <a href="%s" target="_blank">privacy policy</a>.':
                if (BOOKING_LOCALE == 'hu_HU') {
                    // %s = get_privacy_policy_url()
                    $translation = 'Elfogadom a <a href="%s" target="_blank">felhasználási feltételeket</a>.';
                }
                break;
            
            default :
        }
    }

    return $translation;
}
add_filter( 'gettext', 'my_booking_translate_text', 10, 3 );

function book_an_appointment_961_after_user_confirmation($token) {
    // [...]
}
add_action('book_an_appointment_after_user_confirmation', 'book_an_appointment_961_after_user_confirmation', 10, 1);

function book_an_appointment_961_after_user_cancelled($token) {
    // [...]
}
add_action('book_an_appointment_after_user_cancelled', 'book_an_appointment_961_after_user_cancelled', 10, 1);

